@@ -50,7 +50,8 @@ sub parse_options {
         'r|reload'     => sub { $self->{loader} = "Restarter" },
         'R|Reload=s'   => sub { $self->{loader} = "Restarter"; $self->loader->watch(split ",", $_[1]) },
         'L|loader=s'   => \$self->{loader},
-        "h|help",      => \$self->{help},
+        "h|help"       => \$self->{help},
+        "v|version"    => \$self->{version},
     );
 
     my(@options, @argv);
@@ -60,8 +61,10 @@ sub parse_options {
             $v[0] =~ tr/-/_/;
             if (@v == 2) {
                 push @options, @v;
+            } elsif ($v[0] =~ s/^(disable|enable)_//) {
+                push @options, $v[0], $1 eq 'enable';
             } else {
-                push @options, @v, shift @ARGV;
+                push @options, $v[0], shift @ARGV;
             }
         } else {
             push @argv, $_;
@@ -104,6 +107,14 @@ sub mangle_host_port_socket {
     return host => $host, port => $port, listen => \@listen, socket => $socket;
 }
 
+sub version_cb {
+    my $self = shift;
+    $self->{version_cb} || sub {
+        require Plack;
+        print "Plack $Plack::VERSION\n";
+    };
+}
+
 sub setup {
     my $self = shift;
 
@@ -112,6 +123,11 @@ sub setup {
         Pod::Usage::pod2usage(0);
     }
 
+    if ($self->{version}) {
+        $self->version_cb->();
+        exit;
+    }
+
     lib->import(@{$self->{includes}}) if @{$self->{includes}};
 
     if ($self->{eval}) {
