@@ -11,6 +11,7 @@ use Test::TCP;
 use Plack::Loader;
 use Plack::Middleware::Lint;
 use Plack::Util;
+use Plack::Request;
 use Try::Tiny;
 
 my $share_dir = try { File::ShareDir::dist_dir('Plack') } || 'share';
@@ -307,12 +308,7 @@ our @TEST = (
         },
     ],
     [
-        # PEP-333 says:
-        #    If the iterable returned by the application has a close() method,
-        #   the server or gateway must call that method upon completion of the
-        #   current request, whether the request was completed normally, or
-        #   terminated early due to an error. 
-        'call close after read file-like',
+        'call close after read IO::Handle-like',
         sub {
             my $cb  = shift;
             my $res = $cb->(GET "http://127.0.0.1/call_close");
@@ -321,14 +317,13 @@ our @TEST = (
         sub {
             my $env = shift;
             {
-                package CalledClose;
                 our $closed = -1;
-                sub new { $closed = 0; my $i=0; bless \$i, 'CalledClose' }
-                sub getline {
+                sub CalledClose::new { $closed = 0; my $i=0; bless \$i, 'CalledClose' }
+                sub CalledClose::getline {
                     my $self = shift;
                     return $$self++ < 4 ? $$self : undef;
                 }
-                sub close     { ::ok(1, 'closed') if defined &::ok }
+                sub CalledClose::close { ::ok(1, 'closed') if defined &::ok }
             }
             return [
                 200,
@@ -535,7 +530,7 @@ our @TEST = (
                 ]);
             }
         },
-     ],
+    ],
     [
         'coderef streaming',
         sub {
@@ -564,9 +559,9 @@ our @TEST = (
                 $writer->close();
             }
         },
-     ],
-     [
-         'CRLF output and FCGI parse bug',
+    ],
+    [
+        'CRLF output and FCGI parse bug',
         sub {
             my $cb = shift;
             my $res = $cb->(GET "http://127.0.0.1/");
@@ -577,9 +572,9 @@ our @TEST = (
         sub {
             return [ 200, [ "Content-Type", "text/plain" ], [ "Foo: Bar\r\n\r\nHello World" ] ];
         },
-     ],
-     [
-         'test 404',
+    ],
+    [
+        'test 404',
         sub {
             my $cb = shift;
             my $res = $cb->(GET "http://127.0.0.1/");
@@ -589,7 +584,36 @@ our @TEST = (
         sub {
             return [ 404, [ "Content-Type", "text/plain" ], [ "Not Found" ] ];
         },
-     ],
+    ],
+    [
+        'request->input seekable',
+        sub {
+            my $cb = shift;
+            my $req = HTTP::Request->new(POST => "http://127.0.0.1/");
+            $req->content("body");
+            $req->content_type('text/plain');
+            $req->content_length(4);
+            my $res = $cb->($req);
+            is $res->content, 'body';
+        },
+        sub {
+            my $req = Plack::Request->new(shift);
+            return [ 200, [ "Content-Type", "text/plain" ], [ $req->content ] ];
+        },
+    ],
+    [
+        'request->content on GET',
+        sub {
+            my $cb = shift;
+            my $res = $cb->(GET "http://127.0.0.1/");
+            ok $res->is_success;
+        },
+        sub {
+            my $req = Plack::Request->new(shift);
+            $req->content;
+            return [ 200, [ "Content-Type", "text/plain" ], [ "OK" ] ];
+        },
+    ],
 );
 
 sub runtests {
